pub async fn create_post(
configuration: &Configuration,
params: CreatePostParams,
) -> Result<Post, Error<CreatePostError>>Expand description
Create a new post in a channel. To create the post as a comment on another post, provide root_id. ##### Permissions Must have create_post permission for the channel the post is being created in.